PenUp class

Raises the pen up.

After PenUp is called, commands like Forward and Back would not draw lines.

Implemented types
Annotations

Constructors

PenUp()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createInstruction(TurtleState turtle, Map argv) → List<Instruction>
Creates instructions.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited