TurtleState class

Represents the state of a turtle.

Constructors

TurtleState()

Properties

color ↔ Color
The color of the turtle.
getter/setter pair
degrees ↔ double
The angle of the turtle.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isPenDown ↔ bool
If the pen is down.
getter/setter pair
labelHeight ↔ double
Height of labels.
getter/setter pair
macros ↔ Map<String, Macro>
The macros.
getter/setter pair
position ↔ Offset
The position of the turtle.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strokeWidth ↔ double
The current stroke width.
getter/setter pair
turtleStack ↔ Queue
A queue that keeps track of the turtle's movements in a record (Offset, double).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited